@@ -39,6 +39,11 @@ class ServerListenable:
         pass
     def handle_aux(self,req,connection):
         pass
+    def send_file_headers(self, connection, typ):
+        connection.send("HTTP/1.0 200 OK\n".encode())
+        bork = "Content-Type: " + typ + "\n"
+        connection.send(bork.encode())
+        connection.send("\n".encode())
     def parseRequest(self,data):
         copy=data.decode()
         copy=copy.replace("\r","")
